// Código desarrollado por: R. Martínez Cuenca y Sergio Iserte Agut  (2020, Versión 1.1)



//////////////////////////////////////////////////////////////
//															//
//				Funciones para nivel básico					//
//															//
//////////////////////////////////////////////////////////////


// Función del algoritmo numérico para resolver las ecuaciones
function generateData(magua, mbotella, Vbotella, Rbotella, Rchorro, Pinicial, tSim, Niter) {

	// Lee argumentos de la función

	ml0 = parseFloat(magua);
	mb = parseFloat(mbotella);
	Vb = parseFloat(Vbotella);
	Rb = parseFloat(Rbotella);
	Rc = parseFloat(Rchorro);
	P0 = parseFloat(Pinicial);
	tSim = parseFloat(tSim);
	N = parseFloat(Niter);

	// Define vectores con los valores de las variables en cada paso de tiempo

	var ts = []; // Tiempos de simulación
	var vs = []; // Velocidades
	var Ps = []; // Presiones
	var hs = []; // Presiones en metros
	var mls = []; // Masas de agua
	var Mls = []; // Masas de agua
	var ys = []; // Alturas de la botella
	var rhogs = []; // Densidades de aire
	var as = []; // Aceleraciones
	var Ves = []; // Aceleraciones


	// Constantes básicas

	g = 9.81; // Aceleración gravedad
	rhol = 997; // Densidad del líquido
	rhow = 997; 	// Densidad del agua (para presión en metros)
	rhog0 = 1.185; // Densidad del gas
	rhoa = 1.185; // Densidad del aire
	gamma = 1.4; // COnstante adiabática
	Patm = 101300; // Presión atmosférica
	CD = 1; // Coeficiente de drag


	// Paso a unidades del sistema internacional y cálculos previos

	P0 = P0 * 100000;
	P0 = P0 + Patm; // Presión absoluta
	ml0 = ml0 / 1000;
	mb = mb / 1000;
	Vb = Vb / 1000;
	Rb = Rb / 1000;
	Rc = Rc / 1000;

	dt = tSim / N; // Paso de tiempo para el cálculo iterativo
	Vgas0 = Vb - ml0 / rhol; // Volumen inicial de gas
	Ac = Math.PI * Math.pow(Rc, 2); // Área del chorro
	Ab = Math.PI * Math.pow(Rb, 2); // Área expuesta de la botella
	rhog = rhog0 * P0 / Patm; // Densidad del gas a la presión de trabajo


	// Inicialización del cálculo iterativo

	t = 0;
	ts.push(t); // Tiempo inicial
	v = 0;
	vs.push(v); // Velocidad inicial
	a=0;
	as.push(a); // Aceleración inicial
	P = P0;
	Ps.push(P); // Presión inicial
	hs.push((P-Patm)/(g*rhow)); // Presión inicial
	ml = ml0;
	mls.push(ml); // Masa de agua inicial
	Mls.push(ml*1000); // Masa de agua inicial
	y = 0;
	maxy=0;
	ys.push(y); // Altura inicial
	rhogs.push(rhog); // Densidad inicial del gas
	Vgas = Vgas0; // Volumen de gas inicial
	mg = rhog * Vgas; // Masa de gas inicial
	mt = mb + ml + mg; // Masa total inicial
	isliquid=1;
	dmgdt=0;
	Ve=0;
	Ves.push(Ve);
	
	
	// Cálculo itertativo

	for (i = 1; i <= N; i++) {

		// Fuerzas y cálculo de la aceleración
		Fj = isliquid*2 * Ac * (P - Patm)+(1-isliquid)*Ve*dmgdt; // Fuerza del jet
		FD = 0.5 * CD * rhoa * Ab * v * Math.abs(v); // Fuerza de arrastre (drag)
		Fp = mt * g; // Fuerza del peso
		Ft = Fj - Fp - FD; // Fuerza total
		a = Ft / mt; // Aceleración


		// Actualización de las variables

		if (ml == 0) {

			//Si sale gas
			if (isliquid==1) {rhog0=rhog;P0=P;};
			isliquid=0;
			Ve = Math.sqrt(2 * (P - Patm) / rhog); // Velocidad de salida del jet
			dmgdt = rhog * Ac * Ve;
			mg = Math.max(0, mg - dmgdt * dt);
			rhog = mg / Vb;
			P = Math.max(rhog / rhog0 * P0, Patm);
			

		} else {

			// Si sale agua
			isliquid=1;
			Ve = Math.sqrt(2 * (P - Patm) / rhol); // Velocidad de salida del jet
			dmldt = rhol * Ac * Ve; // Masa de agua perdida por unidad de tiempo
			ml = Math.max(0, ml - dmldt * dt); // Masa actual de líquido
			Vgas = Vb - ml / rhol; // Volumen actual de gas
			rhog = mg / Vgas; // Densidad del gas
			P = Math.max(P0 * Math.pow(Vgas0 / Vgas, gamma), Patm); // Presión actual

		}

		mt = mb + ml + mg; // Masa total actual
		v = v + a * dt; // Velocidad actual
		y = Math.max(0, y + v * dt); // Altura actual
		t = t + dt; // Tiempo actual
		maxy = Math.max(y,maxy);

		// Guardar situación actual en vectores

		ts.push(t); // Tiempo actual
		vs.push(v); // Velocidad actual
		Ps.push(P); // Presión actual
		hs.push((P-Patm)/(g*rhow));	// presión en metros actual
		mls.push(ml); // Masa de agua actual (kg)
		Mls.push(ml*1000); // Masa de agua actual (g)
		ys.push(y); // Altura actual
		rhogs.push(rhog); // Densidad actual del gas
		as.push(a/g);			// Aceleración actual de la botella
		Ves.push(Ve);
	}
	
	var MaxY =  precise(maxy,4);

	return [ts, ys, hs, vs, Mls, MaxY, as, Ves];
}

// Función principal (valida y muestra grágicas)
function finalValidate() {
	var count = 0;
	var istrue1 = true;
	count += validate('magua');
	count += validate('mbotella');
	count += validate('Vbotella');
	count += validate('Rbotella');
	count += validate('Rchorro');
	count += validate('Pinicial');
	count += validate('tSim');
	count += validate('Niter');

	if (count == 8) {
		document.getElementById("errfinal").innerHTML = "";
		var str1="Altura máxima de ";
		var str2=" m.";

		var values = generateData(document.getElementById('magua').value,
				document.getElementById('mbotella').value, document.getElementById('Vbotella').value,
				document.getElementById('Rbotella').value, document.getElementById('Rchorro').value,
				document.getElementById('Pinicial').value, document.getElementById('tSim').value,
				document.getElementById('Niter').value);

		var dataall = [{
				x: values[0],
				y: values[1],
				name: "Elevación (m)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[2],
				name: "Presión (mca)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[3],
				name: "Velocidad (m/s)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[4],
				name: "Masa de agua (g)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[7],
				name: "Aceleración (gs)",
				type: 'scatter',
			}
		];

		//https://plot.ly/javascript/custom-buttons/
		

		var layout = {
			    width: 800,
				height: 500,
				autosize: true,
			title: str1.concat(values[5],str2),
			xaxis: {
				title: 'Tiempo (s)',
			},
			yaxis: {
				title: 'Magnitud',
			},
			//updatemenus: updatemenus
		};

		Plotly.newPlot('myDiv', dataall, layout, {
			showSendToCloud: true
		})
.then(gd => {
  gd.on('plotly_restyle', d => {
    if (d[0].visible === 'legendonly') {
      console.log('on legend toggle off')
    }
    if (d[0].visible === true) {
      console.log('on legend toggle on')
    }
  })
})
;

		//Plotly.addTraces('myDiv', dataPrueba); //tienes que pasarle a la función una variable con la estructura de la variable "data".

	} else {
		document.getElementById('myDiv').innerHTML = "";
		document.getElementById("errfinal").innerHTML = "Revisa el valor introducido en algún campo";
	}
}





//////////////////////////////////////////////////////////////
//															//
//				Funciones para nivel intermedio				//
//															//
//////////////////////////////////////////////////////////////


// Función de validación de cada variable
function generateData2(magua2, mbotella2, Vbotella2, Rbotella2, Rchorro2, Pinicial2, CD2, Kchorro2, tSim2, Niter2) {

	// Lee argumentos de la función
    
	ml0 = parseFloat(magua2);
	mb = parseFloat(mbotella2);
	Vb = parseFloat(Vbotella2);
	Rb = parseFloat(Rbotella2);
	Rc = parseFloat(Rchorro2);
	P0 = parseFloat(Pinicial2);
	CD = parseFloat(CD2);
	Kc = parseFloat(Kchorro2);
	tSim = parseFloat(tSim2);
	N = parseFloat(Niter2);

	// Define vectores con los valores de las variables en cada paso de tiempo

	var ts = []; // Tiempos de simulación
	var vs = []; // Velocidades
	var Ps = []; // Presiones
	var hs = []; // Presiones en metros
	var mls = []; // Masas de agua
	var Mls = []; // Masas de agua
	var ys = []; // Alturas de la botella
	var rhogs = []; // Densidades de aire
	var as = []; // Aceleraciones
	var Ves = []; // Aceleraciones


	// Constantes básicas

	g = 9.81; // Aceleración gravedad
	rhol = 997; // Densidad del líquido
	rhow = 997; 	// Densidad del agua (para presión en metros)
	rhog0 = 1.185; // Densidad del gas
	rhoa = 1.185; // Densidad del aire
	Patm = 101300; // Presión atmosférica
	Pv=0;// Presión vapor


	// Paso a unidades del sistema internacional y cálculos previos

	P0 = P0 * 100000;
	P0 = P0 + Patm; // Presión absoluta
	gamma = 1.4;// COnstante adiabática
	ml0 = ml0 / 1000;
	mb = mb / 1000;
	Vb = Vb / 1000;
	Rb = Rb / 1000;
	Rc = Rc / 1000;

	dt = tSim / N; // Paso de tiempo para el cálculo iterativo
	Vgas0 = Vb - ml0 / rhol; // Volumen inicial de gas
	Ac = Math.PI * Math.pow(Rc, 2); // Área del chorro
	Ab = Math.PI * Math.pow(Rb, 2); // Área expuesta de la botella
	rhog = rhog0 * P0 / Patm; // Densidad del gas a la presión de trabajo


	// Inicialización del cálculo iterativo

	t = 0;
	ts.push(t); // Tiempo inicial
	v = 0;
	vs.push(v); // Velocidad inicial
	a=0;
	as.push(a); // Aceleración inicial
	P = P0;
	Ps.push(P); // Presión inicial
	hs.push((P-Patm)/(g*rhow)); // Presión inicial
	ml = ml0;
	mls.push(ml); // Masa de agua inicial
	Mls.push(ml*1000); // Masa de agua inicial
	y = 0;
	maxy=0;
	ys.push(y); // Altura inicial
	rhogs.push(rhog); // Densidad inicial del gas
	Vgas = Vgas0; // Volumen de gas inicial
	mg = rhog * Vgas; // Masa de gas inicial
	mt = mb + ml + mg; // Masa total inicial
	isliquid=1;
	dmgdt=0;
	Ve=0;
	Ves.push(Ve);
	dmldt=0;
	Cjet=1+Kc-Math.pow(Rc/Rb,4);
	
	// Cálculo itertativo

	for (i = 1; i <= N; i++) {

		// Fuerzas y cálculo de la aceleración
		Fj = isliquid*Ve*dmldt+(1-isliquid)*Ve*dmgdt; // Fuerza del jet
		FD = 0.5 * CD * rhoa * Ab * v * Math.abs(v); // Fuerza de arrastre (drag)
		Fp = mt * g; // Fuerza del peso
		Ft = Fj - Fp - FD; // Fuerza total
		a = Ft / mt; // Aceleración


		// Actualización de las variables

		if (ml == 0) {

			//Si sale gas
			if (isliquid==1) {rhog0=rhog;P0=P;};
			isliquid=0;
			Ve = Math.sqrt(2 * (P - Patm) / (rhog*Cjet)); // Velocidad de salida del jet
			dmgdt = rhog * Ac * Ve;
			mg = Math.max(0, mg - dmgdt * dt);
			rhog = mg / Vb;
			P = Math.max(rhog / rhog0 * P0, Patm);
			

		} else {

			// Si sale agua
			isliquid=1;
			Ve = Math.sqrt(2 * (P - Patm) / (rhol*Cjet)); // Velocidad de salida del jet
			dmldt = rhol * Ac * Ve; // Masa de agua perdida por unidad de tiempo
			ml = Math.max(0, ml - dmldt * dt); // Masa actual de líquido
			Vgas = Vb - ml / rhol; // Volumen actual de gas
			rhog = mg / Vgas; // Densidad del gas
			P = Math.max(P0 * Math.pow(Vgas0 / Vgas, gamma), Patm); // Presión actual

		}

		mt = mb + ml + mg; // Masa total actual
		v = v + a * dt; // Velocidad actual
		y = Math.max(0, y + v * dt); // Altura actual
		t = t + dt; // Tiempo actual
		maxy = Math.max(y,maxy);

		// Guardar situación actual en vectores

		ts.push(t); // Tiempo actual
		vs.push(v); // Velocidad actual
		Ps.push(P); // Presión actual
		hs.push((P-Patm)/(g*rhow));	// presión en metros actual
		mls.push(ml); // Masa de agua actual (kg)
		Mls.push(ml*1000); // Masa de agua actual (g)
		ys.push(y); // Altura actual
		rhogs.push(rhog); // Densidad actual del gas
		as.push(a/g);			// Aceleración actual de la botella
		Ves.push(Ve);
	}
	
	var MaxY =  precise(maxy,4);

	return [ts, ys, hs, vs, Mls, MaxY, as, Ves];
}

// Función principal (valida y muestra grágicas)
function finalValidate2() {
	var count = 0;
	var istrue1 = true;
	count += validate('magua2');
	count += validate('mbotella2');
	count += validate('Vbotella2');
	count += validate('Rbotella2');
	count += validate('Rchorro2');
	count += validate('Pinicial2');
	count += validate('CD2');
	count += validate('Kchorro2');
	count += validate('tSim2');
	count += validate('Niter2');

	if (count == 10) {
		document.getElementById("errfinal2").innerHTML = "";
		var str1="Altura máxima de ";
		var str2=" m.";

		var values = generateData2(document.getElementById('magua2').value,
				document.getElementById('mbotella2').value, document.getElementById('Vbotella2').value,
				document.getElementById('Rbotella2').value, document.getElementById('Rchorro2').value,
				document.getElementById('Pinicial2').value, document.getElementById('CD2').value,
				document.getElementById('Kchorro2').value, //document.getElementById('HR2').value,
				document.getElementById('tSim2').value,	document.getElementById('Niter2').value);

		var dataall = [{
				x: values[0],
				y: values[1],
				name: "Elevación (m)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[2],
				name: "Presión (mca)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[3],
				name: "Velocidad (m/s)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[4],
				name: "Masa de agua (g)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[7],
				name: "Aceleración (gs)",
				type: 'scatter',
			}
		];

		//https://plot.ly/javascript/custom-buttons/
		

		var layout = {
			    width: 800,
				height: 500,
				autosize: true,
			title: str1.concat(values[5],str2),
			xaxis: {
				title: 'Tiempo (s)',
			},
			yaxis: {
				title: 'Magnitud',
			},
			//updatemenus: updatemenus
		};

		Plotly.newPlot('myDiv2', dataall, layout, {
			showSendToCloud: true
		})
.then(gd => {
  gd.on('plotly_restyle', d => {
    if (d[0].visible === 'legendonly') {
      console.log('on legend toggle off')
    }
    if (d[0].visible === true) {
      console.log('on legend toggle on')
    }
  })
})
;

		//Plotly.addTraces('myDiv', dataPrueba); //tienes que pasarle a la función una variable con la estructura de la variable "data".

	} else {
		document.getElementById('myDiv2').innerHTML = "";
		document.getElementById("errfinal2").innerHTML = "Revisa el valor introducido en algún campo 2";
	}
}





//////////////////////////////////////////////////////////////
//															//
//				Funciones para nivel avanzado				//
//															//
//////////////////////////////////////////////////////////////


// Función de validación de cada variable
function generateData3(magua3, mbotella3, Vbotella3, Rbotella3, Rchorro3, Pinicial3, CD3, Kchorro3, HR3, tSim3, Niter3) {

	// Lee argumentos de la función
    
	ml0 = parseFloat(magua3);
	mb = parseFloat(mbotella3);
	Vb = parseFloat(Vbotella3);
	Rb = parseFloat(Rbotella3);
	Rc = parseFloat(Rchorro3);
	P0 = parseFloat(Pinicial3);
	CD = parseFloat(CD3);
	Kc = parseFloat(Kchorro3);
	HR = parseFloat(HR3);
	tSim = parseFloat(tSim3);
	N = parseFloat(Niter3);
	

	// Define vectores con los valores de las variables en cada paso de tiempo

	var ts = []; 	// Tiempos de simulación
	var vs = []; 	// Velocidades
	var Ps = []; 	// Presiones
	var hs = []; 	// Presiones en metros
	var mls = []; 	// Masas de agua
	var Mls = []; 	// Masas de agua
	var ys = []; 	// Alturas de la botella
	var rhogs = []; // Densidades de aire
	var as = []; 	// Aceleraciones
	var Ves = []; 	// Aceleraciones
	var ts_resampled = [];
	var	ys_resampled = [];
	var vs_resampled = [];
	var	as_resampled = [];


	// Constantes básicas

	g = 9.81; 		// Aceleración gravedad
	rhol = 997; 	// Densidad del líquido
	rhow = 997; 	// Densidad del agua (para presión en metros)
	rhog0 = 1.185; 	// Densidad del gas
	rhoa = 1.185; 	// Densidad del aire
	Patm = 101300; 	// Presión atmosférica
	Pv=0;			// Presión vapor
	EBerror=1; 		// Error relativo asumible (en tanto %) en la Ecuación de Bernoulli estacionaria

	
	// Paso a unidades del sistema internacional y cálculos previos

	P0 = P0 * 100000;
	P0 = P0 + Patm; 		// Presión absoluta
	gamma = 1.15+(1.40-1.15)*Math.exp(-36*HR3/100); // COnstante adiabática
	ml0 = ml0 / 1000;		
	mb = mb / 1000;
	Vb = Vb / 1000;
	Rb = Rb / 1000;
	Rc = Rc / 1000;

	dt = tSim / N; 					// Paso de tiempo para el cálculo iterativo
	Vgas0 = Vb - ml0 / rhol; 		// Volumen inicial de gas
	Ac = Math.PI * Math.pow(Rc, 2); // Área del chorro
	Ab = Math.PI * Math.pow(Rb, 2); // Área expuesta de la botella
	rhog = rhog0 * P0 / Patm; 		// Densidad del gas a la presión de trabajo
	Cjet=1-Math.pow(Rc/Rb,4)+Kc;	// Término corrector de pérdidas y diámetros en la Ecuación de Bernoulli

	// Inicialización del cálculo iterativo

	t = 0;
	ts.push(t); 		// Tiempo inicial
	v = 0;
	vs.push(v); 		// Velocidad inicial
	a=0;
	as.push(a); 		// Aceleración inicial
	P = P0;
	Ps.push(P); 				// Presión inicial
	hs.push((P-Patm)/(g*rhow)); // Presión inicial
	ml = ml0;
	mls.push(ml); 		// Masa de agua inicial
	Mls.push(ml*1000); // Masa de agua inicial
	y = 0;
	maxy=0;
	ys.push(y); 		// Altura inicial
	rhogs.push(rhog); 	// Densidad inicial del gas
	Vgas = Vgas0; 		// Volumen de gas inicial
	mg = rhog * Vgas; 	// Masa de gas inicial
	mt = mb + ml + mg; 	// Masa total inicial
	Ve=0;				// Jet inicialmente en reposo
	Ves.push(Ve); 
	isliquid=1;			// Inicialización con líquido a salida
	dmgdt=0;			// Pérdida de masa de gas inicial nula
	dmldt=0;			// Pérdida de masa de líquido inicial nula


	// Cálculo itertativo
	
	for (i = 1; i <= N; i++) {

		// Fuerzas y cálculo de la aceleración al inicio de este paso de tiempo
		
		Fj = (dmldt+dmgdt)*Ve; 							// Fuerza del jet
		FD = 0.5 * CD * rhoa * Ab * v * Math.abs(v); 	// Fuerza de arrastre (drag)
		Fp = mt * g; 									// Fuerza del peso
		Ft = Fj - Fp - FD; 								// Fuerza total
		a = Ft / mt; 									// Aceleración

		// Actualización de las variables

		if (ml == 0) {  //Si sale gas
						
			if (isliquid==1) {rhog0=rhog;P0=P;isliquid=0;dmldt=0;};			// Inicialización y regularización bloque sólo gas
			
			Ve = Math.sqrt(2 * (P - Patm) / (rhog*Cjet)); 		// Velocidad de salida del jet
			dmgdt = rhog * Ac * Ve;								// Pérdida de masa
			mg = Math.max(0, mg - dmgdt * dt);					// Masa de gas actual
			rhog = mg / Vb;										// Densidad actual del gas
			P = Math.max(rhog / rhog0 * P0, Patm);				// Presión actual del gas
			

		} else {	// Si sale agua
			
			EB=-1/2*rhol*Math.pow(Ve,2)*Cjet-g*ml/Ab;			// Ecuación de Bernoulli con pérdidas (sin presión);
			EBratio=1-Math.abs(EB/(P-Patm));					// Error relativo cometido en la aproximación de EB estacionaria
			
			// Cálculo de velocidad de salida del JET con la Ecuación de Bernoulli correspondiente
		
			if (EBratio>(EBerror/100)){																
				dVedt=Math.pow(Ab,2)/(ml*Ac)*(P-Patm-1/2*rhol*Math.pow(Ve,2)*Cjet-g*ml/Ab);			// Ecuación transitoria
				Ve=Ve+dVedt * dt;
			} else {
				Ve = Math.sqrt(2 * (P - Patm) / (rhol*Cjet));										// Ecuación estacionaria
			}
						
			dmldt = rhol * Ac * Ve; 									// Masa de agua perdida por unidad de tiempo
			ml = Math.max(0, ml - dmldt * dt); 							// Masa actual de líquido
			Vgas = Vb - ml / rhol; 										// Volumen actual de gas
			rhog = mg / Vgas; 											// Densidad del gas
			P = Math.max(P0 * Math.pow(Vgas0 / Vgas, gamma), Patm); 	// Presión actual

		}

		mt = mb + ml + mg; 				// Masa total actual
		v = v + a * dt; 				// Velocidad actual
		y = Math.max(0, y + v * dt); 	// Altura actual
		t = t + dt; 					// Tiempo actual
		maxy = Math.max(y,maxy);		// Guarda altura máxima

		// Guardar situación actual en vectores

		ts.push(t); 				// Tiempo actual
		vs.push(v); 				// Velocidad actual
		Ps.push(P); 				// Presión actual
		hs.push((P-Patm)/(g*rhow));	// presión en metros actual
		mls.push(ml); 				// Masa de agua actual (kg)
		Mls.push(ml*1000); 			// Masa de agua actual (g)
		ys.push(y); 				// Altura actual
		rhogs.push(rhog); 			// Densidad actual del gas
		as.push(a/g);				// Aceleración actual de la botella
		Ves.push(Ve);				// Velocidad actual del jet
	}
	
	var MaxY =  precise(maxy,4);	// Guarda altura máxima con cuatro cifras
	
	n=Math.floor(N/100);
	for (i = 1; i <= n; i++) {  //resample data
		ts_resampled.push(ts[100*(i-1)]); 
		ys_resampled.push(ys[100*(i-1)]); 
		vs_resampled.push(vs[100*(i-1)]); 
		as_resampled.push(as[100*(i-1)]); 
	} 


	return [ts, ys, hs, vs, Mls, MaxY, as,Ves, ts_resampled, ys_resampled, vs_resampled, as_resampled];			// Devuelve resultados de la función
}

// Función principal (valida y muestra grágicas)
function finalValidate3() {
	
	var str1="Altura máxima de ";
	var str2=" m.";
	var count = 0;
	var istrue1 = true;
	
	count += validate('magua3');
	count += validate('mbotella3');
	count += validate('Vbotella3');
	count += validate('Rbotella3');
	count += validate('Rchorro3');
	count += validate('Pinicial3');
	count += validate('CD3');
	count += validate('Kchorro3');
	count += validate('HR3');
	count += validate('tSim3');
	count += validate('Niter3');
	

	if (count == 11) {
		document.getElementById("errfinal3").innerHTML = "";


		var values = generateData3(document.getElementById('magua3').value,
				document.getElementById('mbotella3').value, document.getElementById('Vbotella3').value,
				document.getElementById('Rbotella3').value, document.getElementById('Rchorro3').value,
				document.getElementById('Pinicial3').value, document.getElementById('CD3').value,
				document.getElementById('Kchorro3').value, document.getElementById('HR3').value,
				document.getElementById('tSim3').value,	document.getElementById('Niter3').value);

		var dataall = [{
				x: values[0],
				y: values[1],
				name: "Elevación (m)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[2],
				name: "Presión (mca)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[3],
				name: "Velocidad (m/s)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[4],
				name: "Masa de agua (g)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[6],
				name: "Aceleración (gs)",
				type: 'scatter',
			}, {
				x: values[0],
				y: values[7],
				name: "Velocidad del jet (m/s)",
				type: 'scatter',
			}
		];


		var layout = {
			    width: 800,
				height: 500,
				autosize: true,
			title: str1.concat(values[5],str2),
			xaxis: {
				title: 'Tiempo (s)',
			},
			yaxis: {
				title: 'Magnitud',
			},
		};

		Plotly.newPlot('myDiv3', dataall, layout, {
			showSendToCloud: true
		})
	.then(gd => {
		gd.on('plotly_restyle', d => {
			if (d[0].visible === 'legendonly') {
				console.log('on legend toggle off')
			}
			if (d[0].visible === true) {
				console.log('on legend toggle on')
			}
		})
	});

	} else {
		document.getElementById('myDiv3').innerHTML = "";
		document.getElementById("errfinal3").innerHTML = "Revisa el valor introducido en algún campo 2";
	}
}

// Funciones para mostrar 4 cifras en el cartel de altura máxima y comprobar si los datos de entrada son numéricos
function validate(id) {
	console.log(id);
	var field = document.getElementById(id).value;
	var errfield = "err" + id;

	if (!isNumber(field)) {
		document.getElementById(errfield).innerHTML = "<span style='color:red'>¡Valor no válido!<\/span>";
		return 0;
	} else {
		document.getElementById(errfield).innerHTML = "OK!";
		return 1;
	}
}
function precise(x) {
  return Number.parseFloat(x).toPrecision(4);
}
function isNumber(n) {
	return (!isNaN(parseFloat(n)) && isFinite(n));
}